@@ -10,17 +10,20 @@ import pykka
 from mopidy.core import CoreListener
 
 # local imports
-from . import base
+from ..utils import send_webhook
 
 
 logger = logging.getLogger(__name__)
 
 
-class EventReporter(pykka.ThreadingActor, CoreListener, base.BaseReporter):
+class EventReporter(pykka.ThreadingActor, CoreListener):
 
     def __init__(self, config):
         super(EventReporter, self).__init__()
         self.config = config['webhooks']
 
+    def on_start(self):
+        logger.info('EventReporter started.')
+
     def on_event(self, event, **kwargs):
-        self.send_webhook({event: kwargs})
+        send_webhook(self.config, {event: kwargs})
